Class: Aws::PinpointSMSVoice::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::PinpointSMSVoice::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-pinpointsmsvoice/client.rb,
sig/client.rbs
Overview
An API client for PinpointSMSVoice. To construct a client, you need to configure a :region and :credentials.
client = Aws::PinpointSMSVoice::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateConfigurationSetEventDestinationResponseSuccess, _CreateConfigurationSetResponseSuccess, _DeleteConfigurationSetEventDestinationResponseSuccess, _DeleteConfigurationSetResponseSuccess, _GetConfigurationSetEventDestinationsResponseSuccess, _ListConfigurationSetsResponseSuccess, _SendVoiceMessageResponseSuccess, _UpdateConfigurationSetEventDestinationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_configuration_set(params = {}) ⇒ Struct
Create a new configuration set.
-
#create_configuration_set_event_destination(params = {}) ⇒ Struct
Create a new event destination in a configuration set.
-
#delete_configuration_set(params = {}) ⇒ Struct
Deletes an existing configuration set.
-
#delete_configuration_set_event_destination(params = {}) ⇒ Struct
Deletes an event destination in a configuration set.
-
#get_configuration_set_event_destinations(params = {}) ⇒ Types::GetConfigurationSetEventDestinationsResponse
Obtain information about an event destination, including the types of events it reports, the Amazon Resource Name (ARN) of the destination, and the name of the event destination.
-
#list_configuration_sets(params = {}) ⇒ Types::ListConfigurationSetsResponse
List all of the configuration sets associated with your Amazon Pinpoint account in the current region.
-
#send_voice_message(params = {}) ⇒ Types::SendVoiceMessageResponse
Create a new voice message and send it to a recipient's phone number.
-
#update_configuration_set_event_destination(params = {}) ⇒ Struct
Update an event destination in a configuration set.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-pinpointsmsvoice/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
800 801 802 |
# File 'lib/aws-sdk-pinpointsmsvoice/client.rb', line 800 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
803 804 805 |
# File 'lib/aws-sdk-pinpointsmsvoice/client.rb', line 803 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 |
# File 'lib/aws-sdk-pinpointsmsvoice/client.rb', line 773 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::PinpointSMSVoice') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-pinpointsmsvoice' context[:gem_version] = '1.80.0' Seahorse::Client::Request.new(handlers, context) end |
#create_configuration_set(params = {}) ⇒ Struct
Create a new configuration set. After you create the configuration set, you can add one or more event destinations to it.
85 |
# File 'sig/client.rbs', line 85
def create_configuration_set: (
|
#create_configuration_set_event_destination(params = {}) ⇒ Struct
Create a new event destination in a configuration set.
94 |
# File 'sig/client.rbs', line 94
def create_configuration_set_event_destination: (
|
#delete_configuration_set(params = {}) ⇒ Struct
Deletes an existing configuration set.
105 |
# File 'sig/client.rbs', line 105
def delete_configuration_set: (
|
#delete_configuration_set_event_destination(params = {}) ⇒ Struct
Deletes an event destination in a configuration set.
114 |
# File 'sig/client.rbs', line 114
def delete_configuration_set_event_destination: (
|
#get_configuration_set_event_destinations(params = {}) ⇒ Types::GetConfigurationSetEventDestinationsResponse
Obtain information about an event destination, including the types of events it reports, the Amazon Resource Name (ARN) of the destination, and the name of the event destination.
125 |
# File 'sig/client.rbs', line 125
def get_configuration_set_event_destinations: (
|
#list_configuration_sets(params = {}) ⇒ Types::ListConfigurationSetsResponse
List all of the configuration sets associated with your Amazon Pinpoint account in the current region.
136 |
# File 'sig/client.rbs', line 136
def list_configuration_sets: (
|
#send_voice_message(params = {}) ⇒ Types::SendVoiceMessageResponse
Create a new voice message and send it to a recipient's phone number.
147 |
# File 'sig/client.rbs', line 147
def send_voice_message: (
|
#update_configuration_set_event_destination(params = {}) ⇒ Struct
Update an event destination in a configuration set. An event destination is a location that you publish information about your voice calls to. For example, you can log an event to an Amazon CloudWatch destination when a call fails.
174 |
# File 'sig/client.rbs', line 174
def update_configuration_set_event_destination: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
793 794 795 |
# File 'lib/aws-sdk-pinpointsmsvoice/client.rb', line 793 def waiter_names [] end |