Class: Aws::PinpointSMSVoice::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::PinpointSMSVoice::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-pinpointsmsvoice/client.rb
Overview
An API client for PinpointSMSVoice. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::PinpointSMSVoice::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_configuration_set(params = {}) ⇒ Struct
Create a new configuration set.
-
#create_configuration_set_event_destination(params = {}) ⇒ Struct
Create a new event destination in a configuration set.
-
#delete_configuration_set(params = {}) ⇒ Struct
Deletes an existing configuration set.
-
#delete_configuration_set_event_destination(params = {}) ⇒ Struct
Deletes an event destination in a configuration set.
-
#get_configuration_set_event_destinations(params = {}) ⇒ Types::GetConfigurationSetEventDestinationsResponse
Obtain information about an event destination, including the types of events it reports, the Amazon Resource Name (ARN) of the destination, and the name of the event destination.
-
#list_configuration_sets(params = {}) ⇒ Types::ListConfigurationSetsResponse
List all of the configuration sets associated with your Amazon Pinpoint account in the current region.
-
#send_voice_message(params = {}) ⇒ Types::SendVoiceMessageResponse
Create a new voice message and send it to a recipient’s phone number.
-
#update_configuration_set_event_destination(params = {}) ⇒ Struct
Update an event destination in a configuration set.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-pinpointsmsvoice/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
800 801 802 |
# File 'lib/aws-sdk-pinpointsmsvoice/client.rb', line 800 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
803 804 805 |
# File 'lib/aws-sdk-pinpointsmsvoice/client.rb', line 803 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 |
# File 'lib/aws-sdk-pinpointsmsvoice/client.rb', line 773 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::PinpointSMSVoice') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-pinpointsmsvoice' context[:gem_version] = '1.78.0' Seahorse::Client::Request.new(handlers, context) end |
#create_configuration_set(params = {}) ⇒ Struct
Create a new configuration set. After you create the configuration set, you can add one or more event destinations to it.
495 496 497 498 |
# File 'lib/aws-sdk-pinpointsmsvoice/client.rb', line 495 def create_configuration_set(params = {}, = {}) req = build_request(:create_configuration_set, params) req.send_request() end |
#create_configuration_set_event_destination(params = {}) ⇒ Struct
Create a new event destination in a configuration set.
538 539 540 541 |
# File 'lib/aws-sdk-pinpointsmsvoice/client.rb', line 538 def create_configuration_set_event_destination(params = {}, = {}) req = build_request(:create_configuration_set_event_destination, params) req.send_request() end |
#delete_configuration_set(params = {}) ⇒ Struct
Deletes an existing configuration set.
559 560 561 562 |
# File 'lib/aws-sdk-pinpointsmsvoice/client.rb', line 559 def delete_configuration_set(params = {}, = {}) req = build_request(:delete_configuration_set, params) req.send_request() end |
#delete_configuration_set_event_destination(params = {}) ⇒ Struct
Deletes an event destination in a configuration set.
583 584 585 586 |
# File 'lib/aws-sdk-pinpointsmsvoice/client.rb', line 583 def delete_configuration_set_event_destination(params = {}, = {}) req = build_request(:delete_configuration_set_event_destination, params) req.send_request() end |
#get_configuration_set_event_destinations(params = {}) ⇒ Types::GetConfigurationSetEventDestinationsResponse
Obtain information about an event destination, including the types of events it reports, the Amazon Resource Name (ARN) of the destination, and the name of the event destination.
621 622 623 624 |
# File 'lib/aws-sdk-pinpointsmsvoice/client.rb', line 621 def get_configuration_set_event_destinations(params = {}, = {}) req = build_request(:get_configuration_set_event_destinations, params) req.send_request() end |
#list_configuration_sets(params = {}) ⇒ Types::ListConfigurationSetsResponse
List all of the configuration sets associated with your Amazon Pinpoint account in the current region.
655 656 657 658 |
# File 'lib/aws-sdk-pinpointsmsvoice/client.rb', line 655 def list_configuration_sets(params = {}, = {}) req = build_request(:list_configuration_sets, params) req.send_request() end |
#send_voice_message(params = {}) ⇒ Types::SendVoiceMessageResponse
Create a new voice message and send it to a recipient’s phone number.
719 720 721 722 |
# File 'lib/aws-sdk-pinpointsmsvoice/client.rb', line 719 def (params = {}, = {}) req = build_request(:send_voice_message, params) req.send_request() end |
#update_configuration_set_event_destination(params = {}) ⇒ Struct
Update an event destination in a configuration set. An event destination is a location that you publish information about your voice calls to. For example, you can log an event to an Amazon CloudWatch destination when a call fails.
764 765 766 767 |
# File 'lib/aws-sdk-pinpointsmsvoice/client.rb', line 764 def update_configuration_set_event_destination(params = {}, = {}) req = build_request(:update_configuration_set_event_destination, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
793 794 795 |
# File 'lib/aws-sdk-pinpointsmsvoice/client.rb', line 793 def waiter_names [] end |